Struct env_logger::fmt::Formatter [−][src]
pub struct Formatter { /* fields omitted */ }A formatter to write logs into.
Formatter implements the standard Write trait for writing log records.
It also supports terminal colors, through the style method.
Examples
Use the writeln macro to easily format a log record:
use std::io::Write; let mut builder = env_logger::Builder::new(); builder.format(|buf, record| writeln!(buf, "{}: {}", record.level(), record.args()));
Methods
impl Formatter[src]
impl Formatterpub fn style(&self) -> Style[src]
pub fn style(&self) -> StyleBegin a new Style.
Examples
Create a bold, red colored style and use it to print the log level:
use std::io::Write; use env_logger::fmt::Color; let mut builder = env_logger::Builder::new(); builder.format(|buf, record| { let mut level_style = buf.style(); level_style.set_color(Color::Red).set_bold(true); writeln!(buf, "{}: {}", level_style.value(record.level()), record.args()) });
pub fn timestamp(&self) -> Timestamp[src]
pub fn timestamp(&self) -> TimestampGet a Timestamp for the current date and time in UTC.
Examples
Include the current timestamp with the log record:
use std::io::Write; let mut builder = env_logger::Builder::new(); builder.format(|buf, record| { let ts = buf.timestamp(); writeln!(buf, "{}: {}: {}", ts, record.level(), record.args()) });